@@ -297,10 +297,12 @@ def _add_transcript_fraction(subexon_df):
         ['GeneID',
          'SubexonID']).size().to_frame('TranscriptsWithSubexon').reset_index()
 
-    transcript_counts = subexon_df.loc[:, [
-        'GeneID', 'TranscriptID'
-    ]].drop_duplicates().groupby(
-        ['GeneID']).size().to_frame('TranscriptsInGene').reset_index()
+    transcript_counts = subexon_df.loc[:,
+                                       ['GeneID', 'TranscriptID'
+                                        ]].drop_duplicates().groupby([
+                                            'GeneID'
+                                        ]).size().to_frame(
+                                            'TranscriptsInGene').reset_index()
 
     counts = pd.merge(subexon_counts,
                       transcript_counts,
@@ -320,19 +322,19 @@ def _add_transcript_fraction(subexon_df):
 def _find_exon(subexon_table, subexon_id_cluster):
     """Return a list with the 'ExonID's of a particular subexon."""
     return subexon_table.loc[subexon_table['SubexonIDCluster'] ==
-                             subexon_id_cluster, 'ExonIDCluster'].unique(
-                             ).tolist()
+                             subexon_id_cluster,
+                             'ExonIDCluster'].unique().tolist()
 
 
-def _update_to_merge_list(to_merge, subexon_1, subexon_2):
+def update_to_merge_list(to_merge, subexon_1, subexon_2):
     """
     Add subexon_1 and subexon_2 to the to_merge list.
 
-    >>> _update_to_merge_list([], 1, 2)
+    >>> update_to_merge_list([], 1, 2)
     [{1, 2}]
-    >>> _update_to_merge_list([{1, 2}], 2, 3)
+    >>> update_to_merge_list([{1, 2}], 2, 3)
     [{1, 2, 3}]
-    >>> _update_to_merge_list([{1, 2}], 8, 9)
+    >>> update_to_merge_list([{1, 2}], 8, 9)
     [{1, 2}, {8, 9}]
     """
     group = {subexon_1, subexon_2}
@@ -362,12 +364,12 @@ def _fill_subexons_to_merge(subexons_to_merge, subexons, exon_table):
         previous_row = row_list[row_index - 1]
         actual_row = row_list[row_index]
         if (previous_row['SubexonIDCluster'] in subexons) and (
-                actual_row['SubexonIDCluster'] in subexons) and (
-                    previous_row['TranscriptFraction'] ==
-                    actual_row['TranscriptFraction']):
-            to_merge = _update_to_merge_list(to_merge,
-                                             previous_row['SubexonIDCluster'],
-                                             actual_row['SubexonIDCluster'])
+                actual_row['SubexonIDCluster']
+                in subexons) and (previous_row['TranscriptFraction']
+                                  == actual_row['TranscriptFraction']):
+            to_merge = update_to_merge_list(to_merge,
+                                            previous_row['SubexonIDCluster'],
+                                            actual_row['SubexonIDCluster'])
     if to_merge:
         for group in to_merge:
             for subexon in group:
@@ -440,7 +442,12 @@ def _merge_subexon_columns(subexons_df):
     merged_id = ""
     merged_protein = ""
     merged_dna = ""
-    for index in range(1, subexons_df.shape[0]):
+    coding_start = -1
+    coding_end = -1
+    start_phase = -1
+    end_phase = -1
+    n_rows = subexons_df.shape[0]
+    for index in range(1, n_rows):
         rowi = subexons_df.iloc[index - 1, :]  # previous_row
         rowj = subexons_df.iloc[index, :]  # actual_row
         if not merged_id:
@@ -461,11 +468,19 @@ def _merge_subexon_columns(subexons_df):
         else:
             merged_dna = merged_dna + rowj['SubexonSequence']
 
-    return merged_id, merged_dna, merged_protein
+        if index == 1:
+            start_phase = rowi['StartPhase']
+            coding_start = rowi['SubexonCodingStart']
+        if index == (n_rows - 1):
+            end_phase = rowj['EndPhase']
+            coding_end = rowj['SubexonCodingEnd']
+
+    return merged_id, merged_dna, merged_protein, coding_start, coding_end, start_phase, end_phase
 
 
 def _fill_with_new_subexon_data(  # pylint: disable=too-many-arguments
-        old2new, rowi, rowj, merged_id, merged_dna, merged_protein):
+        old2new, rowi, rowj, merged_id, merged_dna, merged_protein,
+        coding_start, coding_end, start_phase, end_phase):
     """Fill a dict from old subexon ID to a dict with the new values."""
     keys = [
         'SubexonID', 'SubexonIDCluster', 'SubexonCodingStart',
@@ -476,14 +491,12 @@ def _fill_with_new_subexon_data(  # pylint: disable=too-many-arguments
     rowj_subexon = rowj['SubexonIDCluster']
     previous = old2new.setdefault(rowi_subexon, rowi[keys].to_dict())
     actual = old2new.setdefault(rowj_subexon, rowj[keys].to_dict())
-    if rowi['Strand'] == 1:
-        previous['SubexonCodingEnd'] = actual['SubexonCodingEnd']
-        actual['SubexonCodingStart'] = previous['SubexonCodingStart']
-    else:
-        actual['SubexonCodingStart'] = previous['SubexonCodingStart']
-        previous['SubexonCodingEnd'] = actual['SubexonCodingEnd']
-    previous['EndPhase'] = actual['EndPhase']
-    actual['StartPhase'] = previous['StartPhase']
+    actual['SubexonCodingStart'] = coding_start
+    actual['SubexonCodingEnd'] = coding_end
+    previous['SubexonCodingStart'] = coding_start
+    previous['SubexonCodingEnd'] = coding_end
+    previous['EndPhase'] = end_phase
+    actual['StartPhase'] = start_phase
     previous['SubexonProteinSequence'] = merged_protein
     actual['SubexonProteinSequence'] = merged_protein
     previous['SubexonSequence'] = merged_dna
@@ -512,8 +525,8 @@ def _merge_subexons(  # pylint: disable=too-many-locals
                                    ascending=True)
             assert len(transcript) == n_subexons
 
-            merged_id, merged_dna, merged_protein = _merge_subexon_columns(
-                transcript)
+            (merged_id, merged_dna, merged_protein, coding_start, coding_end,
+             start_phase, end_phase) = _merge_subexon_columns(transcript)
 
             old2new = {}
             for index in range(1, n_subexons):
@@ -521,7 +534,8 @@ def _merge_subexons(  # pylint: disable=too-many-locals
                 actual_row = transcript.iloc[index, :]
                 _fill_with_new_subexon_data(old2new, previous_row, actual_row,
                                             merged_id, merged_dna,
-                                            merged_protein)
+                                            merged_protein, coding_start,
+                                            coding_end, start_phase, end_phase)
 
             for index in group_index:
                 subexon_id = subexon_table.loc[index, 'SubexonIDCluster']
