@@ -68,14 +68,11 @@ def _in_species_list(species, species_list=None):
     return species in species_list
 
 
-def read_tsl_file(tsl_file,
-                  maximum_tsl_level,
-                  remove_na=False,
-                  species_list=None):
+def read_tsl_file(tsl_file, max_tsl_level, remove_na=False, species_list=None):
     """
     Read a csv file with the Transcript Support Level (TSL) data.
 
-    `maximum_tsl_level` determines the maximum Transcript Support Level (TSL)
+    `max_tsl_level` determines the maximum Transcript Support Level (TSL)
     level to keep. The options are:
 
     - 1.0 : All splice junctions of the transcript are supported by at
@@ -91,7 +88,7 @@ def read_tsl_file(tsl_file,
 
     It returns a pandas DataFrame with MultiIndex: ('Species', 'TranscriptID').
     """
-    assert maximum_tsl_level in {1.0, 2.0, 3.0, 4.0, 5.0}
+    assert max_tsl_level in {1.0, 2.0, 3.0, 4.0, 5.0}
 
     # TO DO : Modify EnsemblRESTTranscriptQueries.py to make stable the input
     #         of this function:
@@ -115,17 +112,25 @@ def read_tsl_file(tsl_file,
         for row in tsl_data.itertuples()
     ]]
 
-    selected_flags = [
-        # explicit convert to float, sometimes Flags are read as str
-        _get_flag(row.Flags) <= maximum_tsl_level
-        for row in tsl_data.itertuples()
-    ]
+    # explicit convert to float, sometimes Flags are read as str
+    tsl_data["TSL"] = tsl_data.Flags.map(_get_flag)
+    tsl_data.drop(columns=['Flags'], inplace=True)
+    selected_flags = tsl_data.TSL <= max_tsl_level
+
     if remove_na:
+        to_delete = set(tsl_data.TranscriptID[~selected_flags])
         tsl_data = tsl_data[selected_flags]
     else:
-        missing_tsl = tsl_data.Flags.isna()
+        missing_tsl = tsl_data.TSL.isna()
+        to_delete = set(tsl_data.TranscriptID[~(selected_flags | missing_tsl)])
         tsl_data = tsl_data[selected_flags | missing_tsl]
 
+    if to_delete:
+        clusters.inform_about_deletions(
+            to_delete,
+            "There are transcripts with TSL greater than {}{}:".format(
+                max_tsl_level, " or no TSL information" if remove_na else ""))
+
     return tsl_data
 
 
@@ -584,7 +589,8 @@ def _identical_seqs(rowi, rowj, seq_column='ExonProteinSequence'):  # pylint: di
     if len(seq_i) != len(seq_j):
         return False
 
-    seq_i, seq_j = _get_comparable_seq(seq_i, seq_j, rowi['StartPhase'], rowi['EndPhase'])
+    seq_i, seq_j = _get_comparable_seq(seq_i, seq_j, rowi['StartPhase'],
+                                       rowi['EndPhase'])
 
     return seq_i == seq_j
 
@@ -638,11 +644,14 @@ def delete_incomplete_sequences(data_frame):
         incomplete_seqs.index[incomplete_seqs['ExonProteinSequence']]).union(
             incomplete_cdss.index[incomplete_cdss['IncompleteCDS']])
 
-    data_frame.drop([
-        i for i in data_frame.index
-        if data_frame.loc[i, 'TranscriptID'] in incomplete_transcripts
-    ],
-                    inplace=True)
+    if incomplete_transcripts:
+        clusters.inform_about_deletions(incomplete_transcripts,
+                                        "Incomplete transcripts were found:")
+        data_frame.drop([
+            i for i in data_frame.index
+            if data_frame.loc[i, 'TranscriptID'] in incomplete_transcripts
+        ],
+                        inplace=True)
 
 
 def delete_badquality_sequences(data_frame):
@@ -658,11 +667,15 @@ def delete_badquality_sequences(data_frame):
     badquality_transcripts = set(
         badquality_seqs.index[badquality_seqs['ExonProteinSequence']])
 
-    data_frame.drop([
-        i for i in data_frame.index
-        if data_frame.loc[i, 'TranscriptID'] in badquality_transcripts
-    ],
-                    inplace=True)
+    if badquality_transcripts:
+        clusters.inform_about_deletions(
+            badquality_transcripts,
+            "Transcripts with bad quality sequences were found:")
+        data_frame.drop([
+            i for i in data_frame.index
+            if data_frame.loc[i, 'TranscriptID'] in badquality_transcripts
+        ],
+                        inplace=True)
 
 
 def find_identical_sequences(data_frame):
